@@ -1,4 +1,3 @@
-import sys
 import time
 from typing import Generator, List, Optional, Tuple, Union
 
@@ -79,18 +78,12 @@ class GrpcClient:
 
         if not bypass_version_check:
             try:
-                if sys.version_info >= (3, 8):
-                    from importlib.metadata import version
+                from importlib import metadata
+            except ImportError:  # for Python<3.8
+                import importlib_metadata as metadata
 
-                    nibiru_proto_version = version("nibiru_proto")
-                else:
-                    import pkg_resources
+            nibiru_proto_version = metadata.version("nibiru_proto")
 
-                    nibiru_proto_version = pkg_resources.get_distribution(
-                        "nibiru_proto"
-                    ).version
-            except Exception:
-                pass
             self.assert_compatible_versions(
                 nibiru_proto_version=nibiru_proto_version,
                 chain_nibiru_version=str(self.get_version()),
